%ifarch %{arm} %{ix86} s390x
%global _lto_cflags %nil
%endif

%ifarch %{arm} %{ix86}
%global lxcflag -DDISABLE_LXC=ON
%else
%global lxcflag -DDISABLE_LXC=OFF
%endif

%global soversion 12

Name:           libxc
Summary:        Library of exchange and correlation functionals for density-functional theory
Version:        6.2.2
Release:    2%{?dist}
License:        MPLv2.0
Source0:        https://gitlab.com/libxc/libxc/-/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:         libxc-5.1.4-pylibxc.patch
URL:            http://www.tddft.org/programs/octopus/wiki/index.php/Libxc

BuildRequires:  make
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-gfortran
BuildRequires:  python3-devel
BuildRequires:  python3-numpy
BuildRequires:  python3-setuptools

%description
libxc is a library of exchange and correlation functionals. Its purpose is to
be used in codes that implement density-functional theory. For the moment, the
library includes most of the local density approximations (LDAs), generalized
density approximation (GGAs), and meta-GGAs. The library provides values for
the energy density and its 1st, 2nd, 3rd, and 4th derivatives.

%package devel
Summary:        Development library and headers for libxc
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig
Requires:       cmake

%description devel
libxc is a library of exchange and correlation functionals. Its purpose is to
be used in codes that implement density-functional theory. For the moment, the
library includes most of the local density approximations (LDAs), generalized
density approximation (GGAs), and meta-GGAs. The library provides values for
the energy density and its 1st, 2nd, 3rd, and 4th derivatives.

This package contains the development headers and library that are necessary
in order to compile programs against libxc.

%package -n python3-%{name}
Summary:        Python3 interface to libxc
Requires:       python3-numpy
Requires:       %{name} = %{version}-%{release}
%description -n python3-%{name}
libxc is a library of exchange and correlation functionals. Its purpose is to
be used in codes that implement density-functional theory. For the moment, the
library includes most of the local density approximations (LDAs), generalized
density approximation (GGAs), and meta-GGAs. The library provides values for
the energy density and its 1st, 2nd, 3rd, and 4th derivatives.

This package contains the Python3 interface library to libxc.

%prep
%setup -q
%patch0 -p1 -b .pylibxc
sed -i "s|@SOVERSION@|%{soversion}|g;s|@LIBDIR@|%{_libdir}|g" pylibxc/core.py

%build
export CFLAGS="%{optflags} -fno-var-tracking-assignments"
%cmake -DDISABLE_VXC=OFF -DDISABLE_FXC=OFF -DDISABLE_KXC=OFF %{lxcflag} -DENABLE_FORTRAN=ON -DENABLE_PYTHON=ON -DENABLE_XHOST=OFF
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_fmoddir}
mv %{buildroot}%{_includedir}/*.mod %{buildroot}%{_fmoddir}
mkdir -p %{buildroot}%{python3_sitearch}
mv %{buildroot}%{_libdir}/pylibxc %{buildroot}%{python3_sitearch}

rm -f %{buildroot}%{_includedir}/libxc.bib


%check
%ctest --parallel 1

%files
%doc README NEWS AUTHORS ChangeLog.md libxc.bib
%license COPYING
%{_bindir}/xc-info
%{_libdir}/libxc.so.%{soversion}*
%{_libdir}/libxcf90.so.%{soversion}*
%{_libdir}/libxcf03.so.%{soversion}*

%files devel
%{_libdir}/libxc.so
%{_libdir}/libxcf90.so
%{_libdir}/libxcf03.so
%{_includedir}/xc*.h
%{_fmoddir}/xc_f90_*.mod
%{_fmoddir}/xc_f03_*.mod
%{_libdir}/pkgconfig/libxc.pc
%{_libdir}/pkgconfig/libxcf03.pc
%{_libdir}/pkgconfig/libxcf90.pc
%{_libdir}/cmake/Libxc/

%files -n python3-%{name}
%{python3_sitearch}/pylibxc/

%changelog
* Wed Jun 11 2025 bbrucezhang <bbrucezhang@tencent.com> - 6.2.2-2
- Rebuilt for loongarch64

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.2.2-1
- initial build
